# RootResource

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** |  | [optional] 
**application** | **str** |  | [optional] 
**version** | **str** |  | [optional] 
**api_version** | **str** |  | [optional] 
**installation_id** | **str** |  | [optional] 
**is_early_access_program** | **bool** |  | [optional] [default to False]
**has_long_term_support** | **bool** |  | [optional] [default to False]
**last_modified_on** | **datetime** |  | [optional] 
**last_modified_by** | **str** |  | [optional] 
**links** | **dict(str, str)** |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


